# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
from .connection_status_state import ConnectionStatusState
import typing
from .provider_mfa_request import ProviderMfaRequest
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ConnectionStatus(UniversalBaseModel):
    state: ConnectionStatusState
    redirect_url: typing.Optional[str] = None
    error_type: typing.Optional[str] = None
    error: typing.Optional[str] = None
    provider_mfa: typing.Optional[ProviderMfaRequest] = None
    success: bool

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
