# This file was auto-generated by Fern from our API Definition.

import typing
from .aggregate_expr import AggregateExpr
from .sleep_column_expr import SleepColumnExpr
from .activity_column_expr import ActivityColumnExpr
from .index_column_expr import IndexColumnExpr
from .group_key_column_expr import GroupKeyColumnExpr

QueryInstructionSelectItem = typing.Union[
    AggregateExpr, SleepColumnExpr, ActivityColumnExpr, IndexColumnExpr, GroupKeyColumnExpr
]
